@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::Defaults::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::Defaults::VERSION = '0.14';
+  $Reply::Plugin::Defaults::VERSION = '0.15';
 }
 
 # XXX Eval::Closure imposes its own hints on things that are eval'ed at the
@@ -21,6 +21,15 @@ use base 'Reply::Plugin';
 
 use Eval::Closure;
 
+sub new {
+    my $class = shift;
+
+    my $self = $class->SUPER::new(@_);
+    $self->{quit} = 0;
+
+    return $self;
+}
+
 sub prompt { "> " }
 
 sub read_line {
@@ -85,4 +94,28 @@ sub print_result {
         if @result;
 }
 
+sub command_q {
+    my $self = shift;
+    $self->{quit} = 1;
+    return '';
+}
+
+sub loop {
+    my $self = shift;
+    my ($continue) = @_;
+
+    $continue = 0 if $self->{quit};
+
+    return $continue;
+}
+
+=begin Pod::Coverage
+
+  new
+  command_q
+
+=end Pod::Coverage
+
+=cut
+
 1;
